@@ -4,7 +4,7 @@ import pytest
 from unittest import mock
 from copy import deepcopy
 
-from httpx import AsyncClient
+from httpx import AsyncClient, ASGITransport
 
 from authlib.common.security import generate_token
 from authlib.common.urls import url_encode
@@ -96,7 +96,7 @@ async def test_add_token_to_streaming_request(assert_func, token_placement):
         token_placement="header",
         app=AsyncMockDispatch({'a': 'a'}, assert_func=assert_token_in_header)
     ),
-    AsyncClient(app=AsyncMockDispatch({'a': 'a'}))
+    AsyncClient(transport=ASGITransport(app=AsyncMockDispatch({'a': 'a'})))
 ])
 async def test_httpx_client_stream_match(client):
     async with client as client_entered:
